pub struct ClientBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ClientBuilder<'a>
impl<'a> ClientBuilder<'a>
pub fn new(target: &'a str) -> Self
Sourcepub fn credentials(self, username: &'a str, password: &'a str) -> Self
pub fn credentials(self, username: &'a str, password: &'a str) -> Self
Configure credentials to use for connecting to the target device.
Sourcepub fn tls(
self,
ca_certificate: impl AsRef<[u8]>,
domain_name: impl Into<String>,
) -> Self
pub fn tls( self, ca_certificate: impl AsRef<[u8]>, domain_name: impl Into<String>, ) -> Self
Configure TLS to use for connecting to the target device.
Sourcepub fn dangerous(self) -> DangerousClientBuilder<'a>
Available on crate feature dangerous_configuration only.
pub fn dangerous(self) -> DangerousClientBuilder<'a>
dangerous_configuration only.Access configuration options that are dangerous and require extra care.
Sourcepub async fn build(
self,
) -> Result<Client<InterceptedService<Channel, AuthInterceptor>>, GinmiError>
pub async fn build( self, ) -> Result<Client<InterceptedService<Channel, AuthInterceptor>>, GinmiError>
Consume the ClientBuilder and return a Client.
Errors
- Returns
GinmiError::InvalidUriErrorif specified target is not a valid URI. - Returns
GinmiError::TransportErrorif the TLS-Settings are invalid. - Returns
GinmiError::TransportErrorif a connection to the target could not be established.